@@ -180,7 +180,7 @@ impl<'a> Contents<'a> {
     ///     ::from_action_elements(vec![])
     ///     .with_block_id(long_string);
     ///
-    /// assert_eq!(true, matches!(block.validate(), Err(_)));
+    /// assert!(matches!(block.validate(), Err(_)));
     /// ```
     pub fn validate(&self) -> ValidationResult {
         Validate::validate(self)
@@ -210,6 +210,9 @@ pub enum BlockElement<'a> {
 
     /// All Select types are supported.
     SelectUser(select::User<'a>),
+
+    /// All Select types are supported.
+    SelectExternal(select::External<'a>),
 }
 
 convert!(impl<'a> From<Vec<self::BlockElement<'a>>> for Contents<'a>
@@ -247,6 +250,7 @@ impl<'a> TryFrom<block_elements::BlockElement<'a>> for self::BlockElement<'a> {
         match el {
             El::SelectPublicChannel(sel) => Ok(SelectPublicChannel(sel)),
             El::SelectConversation(sel) => Ok(SelectConversation(sel)),
+            El::SelectExternal(sel) => Ok(SelectExternal(sel)),
             El::SelectUser(sel) => Ok(SelectUser(sel)),
             El::OverflowMenu => Ok(OverflowMenu),
             El::RadioButtons => Ok(RadioButtons),
@@ -262,4 +266,5 @@ impl<'a> TryFrom<block_elements::BlockElement<'a>> for self::BlockElement<'a> {
 convert!(impl<'a> From<select::PublicChannel<'a>> for self::BlockElement<'a> => |s| self::BlockElement::SelectPublicChannel(s));
 convert!(impl<'a> From<select::Conversation<'a>> for self::BlockElement<'a>  => |s| self::BlockElement::SelectConversation(s));
 convert!(impl<'a> From<select::User<'a>> for self::BlockElement<'a>  => |s| self::BlockElement::SelectUser(s));
+convert!(impl<'a> From<select::External<'a>> for self::BlockElement<'a>  => |s| self::BlockElement::SelectExternal(s));
 convert!(impl     From<Button> for self::BlockElement<'static> => |b| self::BlockElement::Button(b));
